@@ -79,6 +79,7 @@ class Yaml_Config(object):
     
     def init_store(self):
         schemes = self.settings.get('schemes', {})
+        _scheme_dict = {}
         for scheme in schemes:
             #if not hasattr(self.app, scheme.get('storm')):
             key = scheme.get('scheme', '')
@@ -100,7 +101,8 @@ class Yaml_Config(object):
             store = scheme.get("storm", None)
             if store: self.init_storm(store, connection)
             session = scheme.get("sqlalchemy", None)
-            if session: self.init_sqlalchemy(scheme, connection)
+            if session: dic = self.init_sqlalchemy(scheme, connection); _scheme_dict["%s" % scheme.get("alias", "") or scheme.get("db", "")] = dic
+        setattr(self.app, 'sqlalchemy_config', _scheme_dict)
     def init_storm(self, store, connection):
         try:
             import storm
@@ -140,8 +142,9 @@ class Yaml_Config(object):
             session = scoped_session(sessionmaker(bind=engine, query_cls=CacheQuery))
             sqlalchemy_sessions = [session]
             DB_Session = sessionmaker(bind=engine)
-            setattr(self.app, 'metadata', metadata)
-            setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
-            setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
+            return {"metadata":metadata, "session":session, "sqlalchemy_sessions":sqlalchemy_sessions}
+            #setattr(self.app, 'metadata', metadata)
+            #setattr(self.app, scheme.get('sqlalchemy', 'session'), session)
+            #setattr(self.app, 'sqlalchemy_sessions', sqlalchemy_sessions)
         except Exception as e:
             print e
